 /*
  * Mike's Raycaster 0.5 - A demonstration of raycasting in java
  * 	http://mike.bitrevision.com/raycaster/
  * 
  * Copyright (c) 2008-2012 Michael Billington <michael.billington@gmail.com>
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:

  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.

  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  * THE SOFTWARE. */

import java.io.*;

public class GameMap {
	byte[][] tile;
	int width = 0;
	int height = 0;
	String name;

	public GameMap(String file_path) {
		System.out.println("GameMap(): Loading map: " + file_path);

		/* Load a file from string */
		try {
			String file_data = file_get_contents(file_path);
			String lines[] = file_data.split("\n");
			height = lines.length - 1;
			if(height < 1) {
				System.out.println("GameMap(): Map not long enough. Aborting.");
				System.exit(0);
			}
			name = lines[0];

			int x;
			int y;
			byte[] line;
			width = lines[1].length();
			tile = new byte[width][height];

			for(y = 1; y <= height; y++) {
				line = lines[y].getBytes(); 
				if(line.length < width) {
					System.out.println("GameMap(): Error on line " + y + " of " + file_path + ", line is not long enough");
					System.exit(0);
				}
				
				for(x = 0; x < width; x++) {
					if(line[x] == 'X') {
						Engine.player.moveTo(new PlayerPos(-Math.PI / 2, x, y - 1, Raycaster.BLOCK_SIZE / 2, Raycaster.BLOCK_SIZE / 2));
						tile[x][y-1] = ' ';
					} else {
						tile[x][y-1] = line[x];
					}
					System.out.print((char)line[x]);
				}
				System.out.print("\n");
			}
			System.out.println("GameMap(): Height: " + height + ", Width: " + width);
		} catch (FileNotFoundException e) {
			System.out.println(e.toString());
			System.exit(0);
		}
	}

	public String getName() {
		return name;
	}

	private static String file_get_contents(String file_path) throws FileNotFoundException {
		/* Load file into a string */
		int length;
		byte[] file_data;
		length = (int) new File(file_path).length();
		file_data = new byte[length];

		BufferedInputStream file = null;
		try {
			file = new BufferedInputStream(new FileInputStream(file_path));
			file.read(file_data);
			file.close();
		} catch(Exception e) {
			throw new FileNotFoundException(file_path + " could not be read.");
		}
	
		return new String(file_data);
	}
}
