 /*
  * Mike's Raycaster 0.5 - A demonstration of raycasting in java
  * 	http://mike.bitrevision.com/raycaster/
  * 
  * Copyright (c) 2008-2012 Michael Billington <michael.billington@gmail.com>
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:

  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.

  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  * THE SOFTWARE. */

class Player {
	/* Classed used to move/turn the player */

	private static double curAngle = 0;
	private static double curX = 0;
	private static double curY = 0;
	public static PlayerPos pos = new PlayerPos(curAngle, curX, curY);

	public void move(double amountOffset) {
		curX += amountOffset * Math.cos(curAngle);
		curY += amountOffset * Math.sin(curAngle);
		pos = new PlayerPos(curAngle, curX, curY);
	}

	public void turn(double angleOffset) {
		/* Turn player number of radians, then check if we are still 0-2pi radians */
		curAngle += angleOffset;
		curAngle = normaliseAngle(curAngle);
		pos = new PlayerPos(curAngle, curX, curY);
	}

	public PlayerPos getPos() {
		return pos;
	}

	static double normaliseAngle(double angle) {
		/* Places an angle between 0 and 2 * pi */
		angle += Math.PI * 2;
		angle %= Math.PI * 2;
		return angle;
	}

	public void moveTo(PlayerPos position) {
		curX = position.BlockX * Raycaster.BLOCK_SIZE + position.PosX;
		curY = position.BlockY * Raycaster.BLOCK_SIZE + position.PosY;
		curAngle = normaliseAngle(position.angle);
		pos = new PlayerPos(curAngle, curX, curY);
	}
}
