 /*
  * Mike's Raycaster 0.5 - A demonstration of raycasting in java
  * 	http://mike.bitrevision.com/raycaster/
  * 
  * Copyright (c) 2008-2012 Michael Billington <michael.billington@gmail.com>
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:

  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.

  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  * THE SOFTWARE. */

import javax.swing.*;
import java.awt.*;

public class Raycaster {
	final static int BLOCK_SIZE = 64;
	final static int WINDOW_WIDTH = 450;
	final static int WINDOW_HEIGHT = 450;

	static JFrame window;
	static DisplayCanvas display;

	public static void main(String[] args) throws InterruptedException {
		/* Setting up paths for resources */;
		final String iconFile = "data/blocks.png";
		String mapFile = "data/map.txt";
		if (args.length >= 1) {
			mapFile = args[0];
		}

		/* Initialising various classes */
		window = new JFrame("Mike's Raycaster");
		window.setIconImage(new ImageIcon(iconFile).getImage());
		Engine.input = new UserInput();
		display = new DisplayCanvas();
		display.setBackground(Color.black);
		display.addKeyListener(Engine.input);

		/* Window business */
		window.setPreferredSize(new Dimension(WINDOW_WIDTH, WINDOW_HEIGHT));
		window.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		window.getContentPane().add(display);
		window.pack();
		display.requestFocusInWindow();
		window.setVisible(true);

		Engine.initialise(mapFile);
		window.setTitle(Engine.map.getName());

		while (true) {
			/* Check for pressed keys and move player as needed */
			Engine.movePlayer();
			display.repaint();
			Thread.sleep(30);
		}
	}
}
