 /*
  * Mike's Raycaster 0.5 - A demonstration of raycasting in java
  * 	http://mike.bitrevision.com/raycaster/
  * 
  * Copyright (c) 2008-2012 Michael Billington <michael.billington@gmail.com>
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
  * in the Software without restriction, including without limitation the rights
  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:

  * The above copyright notice and this permission notice shall be included in
  * all copies or substantial portions of the Software.

  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  * THE SOFTWARE. */

import java.awt.event.*;

public class UserInput implements KeyListener {
	/* Get keyboard input from the user */
	
	/* We only care about a few keys < 255 */
	public final int KEY_COUNT = 256;
	private boolean[] keyState = new boolean[KEY_COUNT];
	
	/* Some key constants */
	public final int KEY_UP		= 38;
	public final int KEY_DOWN	= 40;
	public final int KEY_LEFT	= 37;
	public final int KEY_RIGHT	= 39;
	public final int KEY_SPACE	= 32;
	public final int KEY_ESC	= 27;

	public UserInput() {
		for(int i = 0; i < KEY_COUNT; i++) {
			keyState[i] = false;
		}
	}
	
	public void keyPressed(KeyEvent e) {
		/* Press down a key */
		int code = e.getKeyCode();
		if(code < KEY_COUNT) {
			// System.out.println("Key pressed: " + code);
			if(code == KEY_SPACE) {
				Engine.DISPLAY_2D = !Engine.DISPLAY_2D;
			} else if (code == KEY_ESC) {
				System.exit(0);
			}
			keyState[code] = true;
		}
	}

	public void keyReleased(KeyEvent e) {
		/* Release a key */
		int code = e.getKeyCode();
		if(code < KEY_COUNT) {
			keyState[code] = false;
		}
	}
	
	public boolean getKeyState(int keyCode) {
		if(keyCode < KEY_COUNT) {
			return keyState[keyCode];
		} else {
			return false;
		}
	}

	public void keyTyped(KeyEvent e) {
		/* Not used */
	}
}
